/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2011 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Util.java 20836 2011-02-03 17:17:26Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.admin.autostart.service;

import java.io.IOException;
import java.util.logging.Level;
import java.util.logging.Logger;

import javax.management.AttributeNotFoundException;
import javax.management.InstanceNotFoundException;
import javax.management.MBeanException;
import javax.management.MBeanServerConnection;
import javax.management.MalformedObjectNameException;
import javax.management.ObjectName;
import javax.management.ReflectionException;

import org.ow2.jonas.lib.management.extensions.manager.ManagementEntryPoint;

/**
 * Initialize JOnAS Root and JOnAS Base folder.
 *
 * @author skabore
 */
public class Util {

    /**
     * The EZB JMX server.
     */
    private static transient MBeanServerConnection serv = null;

    /**
     * Domain name.
     */
    private static String domainName = null;

    /**
     * Server name.
     */
    private static String serverName = null;

    /**
     * JOnAS Base.
     */
    private static String jonasBase = null;

    /**
     * JOnAS Root.
     */
    private static String jonasRoot = null;

    /**
     * Initialiaze JOnAS Root and JOnAS Base value.
     */
    public static void init() {
        domainName = ManagementEntryPoint.getInstance().getDomainName();
        serverName = ManagementEntryPoint.getInstance().getServerName();

        serv = ManagementEntryPoint.getInstance().getServerConnection();

        ObjectName j2eeServer = null;
        try {
            j2eeServer = new ObjectName(domainName + ":j2eeType=J2EEServer,name=" + serverName);
        } catch (MalformedObjectNameException e) {
            Logger.getLogger(Util.class.getName()).log(Level.SEVERE, null, e);
        }
        try {
            jonasBase = (String) serv.getAttribute(j2eeServer, "jonasBase");
            jonasRoot = (String) serv.getAttribute(j2eeServer, "jonasRoot");
        } catch (MBeanException ex) {
            Logger.getLogger(Util.class.getName()).log(Level.SEVERE, null, ex);
        } catch (AttributeNotFoundException ex) {
            Logger.getLogger(Util.class.getName()).log(Level.SEVERE, null, ex);
        } catch (InstanceNotFoundException ex) {
            Logger.getLogger(Util.class.getName()).log(Level.SEVERE, null, ex);
        } catch (ReflectionException ex) {
            Logger.getLogger(Util.class.getName()).log(Level.SEVERE, null, ex);
        } catch (IOException ex) {
            Logger.getLogger(Util.class.getName()).log(Level.SEVERE, null, ex);
        }
    }

    /**
     * @return jonasBase the JOnAS Base value.
     */
    public static String getJonasBase() {
        return jonasBase;
    }

    /**
     * Set jonasBase value.
     *
     * @param jonasBase new value.
     */
    public static void setJonasBase(final String jonasBase) {
        Util.jonasBase = jonasBase;
    }

    /**
     * @return jonasRoot the JOnAS Root value
     */
    public static String getJonasRoot() {
        return jonasRoot;
    }

    /**
     * Set jonasRoot value.
     *
     * @param jonasRoot new value.
     */
    public static void setJonasRoot(final String jonasRoot) {
        Util.jonasRoot = jonasRoot;
    }

}
